# Varchar

## Field.varchar(name: str, size: int = 255, params: [FieldParameters](Fields.md#fieldparameters) = { })

```python
from Knexpy import Field

_ = Field.varchar("<name>")
```

```python
from Knexpy import Field

_ = Field.varchar("<name>", 10)
```
